pygeodesy.sphericalNvector.Nvector

Package pygeodesy :: Module sphericalNvector :: Class Nvector |
[frames] | no frames]

# Class Nvector

           object --+
                    |
         named._Named --+
                        |
         named._NamedBase --+
                            |
    vector3dBase.Vector3dBase --+
                                |
                vector3d.Vector3d --+
                                    |
              nvectorBase.NvectorBase --+
                                        |
                                       Nvector

An n-vector is a position representation using a (unit) vector normal to the earth's surface. Unlike lat-/longitude points, n-vectors have no singularities or discontinuities.

For many applications, n-vectors are more convenient to work with than other position representations like lat-/longitude, earth-centred earth-fixed (ECEF) vectors, UTM coordinates, etc.

On a spherical model earth, an n-vector is equivalent to an earth-centred earth-fixed (ECEF) vector.

Note commonality with pygeodesy.ellipsoidalNvector.Nvector.

Instance Methods
toCartesian(self, **Cartesian_and_kwds) Convert this n-vector to `Nvector`-based cartesian (ECEF) coordinates. |
toLatLon(self, **LatLon_and_kwds) Convert this n-vector to an `Nvector`-based geodetic point. |
greatCircle(self, bearing) Compute the n-vector normal to great circle obtained by heading on given (initial) bearing from this point as its n-vector. |
Inherited from `nvectorBase.NvectorBase`: `__init__`, `hStr`, `to2ab`, `to2ll`, `to3abh`, `to3llh`, `to4xyzh`, `toStr`, `toVector3d`, `unit` Inherited from `vector3d.Vector3d`: `bearing`, `circin6`, `circum3`, `circum4_`, `iscolinearWith`, `meeus2`, `nearestOn`, `nearestOn6`, `parse`, `radii11`, `soddy4`, `trilaterate2d2`, `trilaterate3d2` Inherited from `vector3dBase.Vector3dBase`: `__abs__`, `__add__`, `__bool__`, `__ceil__`, `__cmp__`, `__div__`, `__divmod__`, `__eq__`, `__float__`, `__floor__`, `__floordiv__`, `__ge__`, `__gt__`, `__hash__`, `__iadd__`, `__idiv__`, `__ifloordiv__`, `__imatmul__`, `__imod__`, `__imul__`, `__int__`, `__ipow__`, `__isub__`, `__itruediv__`, `__le__`, `__long__`, `__lt__`, `__matmul__`, `__mod__`, `__mul__`, `__ne__`, `__neg__`, `__nonzero__`, `__pos__`, `__pow__`, `__radd__`, `__rdiv__`, `__rdivmod__`, `__rfloordiv__`, `__rmatmul__`, `__rmod__`, `__rmul__`, `__round__`, `__rpow__`, `__rsub__`, `__rtruediv__`, `__sub__`, `__truediv__`, `__trunc__`, `angleTo`, `apply`, `bools`, `cmp`, `cross`, `dividedBy`, `dividedBy_`, `dot`, `equals`, `equirectangular`, `fabs`, `floats`, `floorDividedBy`, `floorDividedBy_`, `intermediateTo`, `ints`, `isconjugateTo`, `isequalTo`, `minus`, `minus_`, `negate`, `others`, `plus`, `plus_`, `pow`, `rotate`, `rotateAround`, `sum`, `times`, `times_`, `to3xyz` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `toRepr` Inherited from `named._Named`: `__format__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| sphericalNvector Get this `Nvector`'s spherical class.
Inherited from `nvectorBase.NvectorBase`: `Ecef`, `H`, `datum`, `ellipsoidalNvector`, `h`, `isEllipsoidal`, `isSpherical`, `lam`, `lat`, `latlon`, `latlonheight`, `latlonheightdatum`, `lon`, `phi`, `philam`, `philamheight`, `philamheightdatum`, `xyzh` Inherited from `vector3dBase.Vector3dBase`: `crosserrors`, `euclid`, `homogeneous`, `length`, `length2`, `x`, `x2y2z2`, `x2y2z23`, `xyz`, `xyz3`, `y`, `z` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### toCartesian (self, **Cartesian_and_kwds) |
Convert this n-vector to `Nvector`-based cartesian (ECEF) coordinates. Arguments: `Cartesian_and_kwds` - Optional Cartesian and Cartesian keyword arguments, like `h`. Use `Cartesian=...` to override this Cartesian class or specify `Cartesian=None`. Returns: The cartesian point (Cartesian) or if `Cartesian` is set to `None`, an Ecef9Tuple`(x, y, z, lat, lon, height, C, M, datum)` with `C` and `M` if available. Raises: `TypeError` - Invalid `Cartesian_and_kwds` argument. Overrides: vector3d.Vector3d.toCartesian

### toLatLon (self, **LatLon_and_kwds) |
Convert this n-vector to an `Nvector`-based geodetic point. Arguments: `LatLon_and_kwds` - Optional LatLon and LatLon keyword arguments, like `height`. Use `LatLon=...` to override this LatLon class or specify `LatLon=None`. Returns: The geodetic point (LatLon) or if `LatLon` is set to `None`, an Ecef9Tuple`(x, y, z, lat, lon, height, C, M, datum)` with `C` and `M` if available. Raises: `TypeError` - Invalid `LatLon_and_kwds` argument. `ValueError` - Invalid `height`. Overrides: nvectorBase.NvectorBase.toLatLon

### greatCircle (self, bearing) |
Compute the n-vector normal to great circle obtained by heading on given (initial) bearing from this point as its n-vector. Direction of vector is such that initial bearing vector b = c × p. Arguments: `bearing` - Initial bearing (compass `degrees360`). Returns: N-vector representing great circle (`Nvector`). Raises: `Valuerror` - Polar coincidence.

Property Details

### sphericalNvector Get this `Nvector`'s spherical class. Get method: sphericalNvector(self) - Get this `Nvector`'s spherical class. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.